An S4 class to represent a vector of rata die.
.DataA numeric vector giving the rata die values.
N. Frerebeau
Rata die (fixed date) are represented as the number of days since 01-01-01 (Gregorian), with negative values for earlier dates.
It is intended that the date should be an integer value, but this is not enforced in the internal representation.
Other classes:
AD-class,
BC-class,
BCE-class,
BP-class,
CE-class,
GregorianCalendar-class,
JulianCalendar-class,
TimeIntervals-class,
TimeScale-class,
TimeSeries-class,
b2k-class
Other time classes:
TimeIntervals-class,
TimeSeries-class